=======
History
=======

0.0.2 (2024-06-01)
------------------

Fix template errors (dates, package name, etc)
Add usage examples (partial components of the pipeline) in README.md

0.0.1 (2024-05-31)
------------------

* First release on PyPI.

1. Design library structure
2. Implement 2 main steps of the VAC
    - ASR
    - CER based Matching
